Struct actix_http::header::Quality
source · [−]pub struct Quality(_);Expand description
Represents a quality used in q-factor values.
The default value is equivalent to q=1.0 (the max value).
Implementation notes
The quality value is defined as a number between 0.0 and 1.0 with three decimal places.
This means there are 1001 possible values. Since floating point numbers are not exact and the
smallest floating point data type (f32) consumes four bytes, we use an u16 value to store
the quality internally.
RFC 7231 5.3.1 gives more information on quality values in HTTP header fields.
Examples
use actix_http::header::{Quality, q};
assert_eq!(q(1.0), Quality::MAX);
assert_eq!(q(0.42).to_string(), "0.42");
assert_eq!(q(1.0).to_string(), "1");
assert_eq!(Quality::MIN.to_string(), "0.001");
assert_eq!(Quality::ZERO.to_string(), "0");Implementations